==> eagle-i-repository-webapp-1.0-MS6.0-sources.jar: jsp/repository/admin/namedGraphs_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.util.Arrays;
import java.util.Collection;
import org.apache.commons.lang.StringEscapeUtils;
import org.openrdf.model.URI;
import org.openrdf.repository.RepositoryConnection;
import org.eaglei.repository.NamedGraph;
import org.eaglei.repository.servlet.WithRepositoryConnection;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.DataRepository;

public final class namedGraphs_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList(1);
    _jspx_dependants.add("/repository/admin/banner.jsp");
  }

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");
      out.write("\n\n\n\n\n\n\n\n\n\n\n  <head>\n    <title>Eagle-I Data Repository Admin - Named Graphs</title>\n  </head>\n");

    try {

      out.write("\n  <body>\n    ");
      out.write("\n\n\n<hr/>\n    <table border=\"0\" width=\"100%\" >\n      <tr>\n        <td width=\"30%\"><a href=\"http://www.eagle-i.org/\"><img border=\"0\" alt=\"Institutional Logo\" align=\"right\"\n               src=\"");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.logo", "/repository/images/eagle-i_admin_logo.png") );
      out.write("\" /></a>\n        </td>\n        <td width=\"40%\"><div align=\"center\">\n          <font size=\"+2\" color=\"black\">\n            Repository Administration Area\n          </font>\n          <p>");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.title", "(Config property <tt>eaglei.repository.title</tt> needs to be set)") );
      out.write("</p>\n        </div></td>\n        <td width=\"30%\">&nbsp;</td>\n      </tr>\n    </table>\n<hr/>\n");
      out.write("\n    <h2>Named Graphs Administration</h2>\n    <table border=\"1\">\n    <tr><th colspan=\"2\">Graph Name or URI</th><th>Content Type</th><th>&nbsp;Size*&nbsp;</th><th>Public?</th></tr>\n");

    RepositoryConnection rc = WithRepositoryConnection.get(request);
    Collection<NamedGraph> ngs = NamedGraph.findAll(request);
    NamedGraph nga[] = ngs.toArray(new NamedGraph[ngs.size()]);
    Arrays.sort(nga);
    for (NamedGraph ng : nga) {
        String ngl = StringEscapeUtils.escapeHtml(ng.getLabel());
 
      out.write("\n      <tr><td><a href=\"/repository/admin/editGraph.jsp?name=");
      out.print( ng.getName() );
      out.write("\">\n                ");
      out.print( ngl );
      out.write("\n              </a></td>\n          <td><form style=\"margin: 0pt;\" action=\"/repository/admin/editGrants.jsp\">\n                <input type=\"hidden\" name=\"type\" value=\"Named Graph\" />\n                <input type=\"hidden\" name=\"label\" value=\"");
      out.print( ngl );
      out.write("\"/>\n                <input type=\"hidden\" name=\"uri\" value=\"");
      out.print( ng.getName() );
      out.write("\"/>\n                <button type=\"submit\">Edit ACL</button></form></td>\n          <td>");
      out.print( ng.isManaged() ?
                  StringEscapeUtils.escapeHtml(ng.getTypeLabel())  :
                  "<div align=\"center\"><i>(Undocumented)<i></div>"
               );
      out.write("</td>\n          <td align=\"right\" style=\"padding: 0em .4em;\"><tt>");
      out.print( String.format("%,d",rc.size(ng.getName())) );
      out.write("</tt></td>\n          <td align=\"center\">");
      out.print( String.valueOf(ng.isAnonymousReadable()) );
      out.write("</td>\n      </tr>\n");

    }

      out.write("\n</table>\n    <i>Click on name to edit named graph properties.</i>\n    <br/>\n    <i><b>(*)</b> \"Size\" is a count of the <u>explicit</u> statements only, inferred ones are omitted.</i>\n    <br/>\n    <br/>\n    <a href=\"/repository/admin/index.jsp\">Return to Admin top level</a>\n  </body>\n");

    // see "try" at start of body tag.
    } catch (ErrorSendingException e) {
        response.sendError(e.getStatus(), e.getMessage());
    }

      out.write("\n</html>\n             \n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.1-MS1.00-sources.jar: jsp/repository/admin/namedGraphs_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.util.Arrays;
import java.util.Collection;
import org.apache.commons.lang.StringEscapeUtils;
import org.openrdf.model.URI;
import org.openrdf.repository.RepositoryConnection;
import org.eaglei.repository.NamedGraph;
import org.eaglei.repository.servlet.WithRepositoryConnection;
import org.eaglei.repository.status.ErrorSendingException;
import org.eaglei.repository.DataRepository;

public final class namedGraphs_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList(1);
    _jspx_dependants.add("/repository/admin/banner.jsp");
  }

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");
      out.write("\n\n\n\n\n\n\n\n\n\n  <head>\n    <meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"/>\n    <title>Eagle-I Data Repository Admin - Named Graphs</title>\n  </head>\n");

    try {

      out.write("\n  <body>\n    ");
      out.write('\n');
      out.write("\n\n<hr/>\n    <table border=\"0\" width=\"100%\" >\n      <tr>\n        <td width=\"30%\"><a href=\"http://www.eagle-i.org/\"><img border=\"0\" alt=\"Institutional Logo\" align=\"right\"\n               src=\"");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.logo", "/repository/images/eagle-i_admin_logo.png") );
      out.write("\" /></a>\n        </td>\n        <td width=\"40%\"><div align=\"center\">\n          <font size=\"+2\" color=\"black\">\n            Repository Administration Area\n          </font>\n          <p>");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.title", "(Config property <tt>eaglei.repository.title</tt> needs to be set)") );
      out.write("</p>\n        </div></td>\n        <td width=\"30%\">&nbsp;</td>\n      </tr>\n    </table>\n<hr/>\n");
      out.write("\n    <h2>Named Graphs Administration</h2>\n    <table border=\"1\">\n    <tr><th colspan=\"2\">Graph Name or URI</th><th>Content Type</th><th>&nbsp;Size*&nbsp;</th><th>Public?</th></tr>\n");

    RepositoryConnection rc = WithRepositoryConnection.get(request);
    Collection<NamedGraph> ngs = NamedGraph.findAll(request);
    NamedGraph nga[] = ngs.toArray(new NamedGraph[ngs.size()]);
    Arrays.sort(nga);
    for (NamedGraph ng : nga) {
        String ngl = StringEscapeUtils.escapeHtml(ng.getLabel());
 
      out.write("\n      <tr><td><a href=\"/repository/admin/editGraph.jsp?name=");
      out.print( ng.getName() );
      out.write("\">\n                ");
      out.print( ngl );
      out.write("\n              </a></td>\n          <td><form style=\"margin: 0pt;\" action=\"/repository/admin/editGrants.jsp\">\n                <input type=\"hidden\" name=\"type\" value=\"Named Graph\" />\n                <input type=\"hidden\" name=\"label\" value=\"");
      out.print( ngl );
      out.write("\"/>\n                <input type=\"hidden\" name=\"uri\" value=\"");
      out.print( ng.getName() );
      out.write("\"/>\n                <button type=\"submit\">Edit ACL</button></form></td>\n          <td>");
      out.print( ng.isManaged() ?
                  StringEscapeUtils.escapeHtml(ng.getTypeLabel())  :
                  "<div align=\"center\"><i>(Undocumented)<i></div>"
               );
      out.write("</td>\n          <td align=\"right\" style=\"padding: 0em .4em;\"><tt>");
      out.print( String.format("%,d",rc.size(ng.getName())) );
      out.write("</tt></td>\n          <td align=\"center\">");
      out.print( String.valueOf(ng.isAnonymousReadable()) );
      out.write("</td>\n      </tr>\n");

    }

      out.write("\n</table>\n    <i>Click on name to edit named graph properties.</i>\n    <br/>\n    <i><b>(*)</b> \"Size\" is a count of the <u>explicit</u> statements only, inferred ones are omitted.</i>\n    <br/>\n    <br/>\n    <a href=\"/repository/admin/index.jsp\">Return to Admin top level</a>\n  </body>\n");

    // see "try" at start of body tag.
    } catch (ErrorSendingException e) {
        response.sendError(e.getStatus(), e.getMessage());
    }

      out.write("\n</html>\n             \n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
